@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Inline;
 
-our $DATE = '2015-07-06'; # DATE
-our $VERSION = '0.14'; # VERSION
+our $DATE = '2015-07-08'; # DATE
+our $VERSION = '0.15'; # VERSION
 
 use 5.010001;
 use strict;
@@ -82,6 +82,12 @@ _
         schema => ['array*', of=>'str*'],
         'x.schema.element_entity' => 'riap_url',
     },
+    skip_format => {
+        summary => 'Assume that function returns raw text that need '.
+            'no formatting, do not offer --format, --json, --naked-res',
+        schema  => 'bool*',
+        default => 0,
+    },
 );
 
 $SPEC{gen_inline_pericmd_script} = {
@@ -288,12 +294,13 @@ sub gen_inline_pericmd_script {
     {
         no strict 'refs';
 
+        my $skip_format = $args{skip_format} ||
+            $meta->{'cmdline.skip_format'};
+
         my @l;
 
         my %copts;
         {
-            my $skip_format = $meta->{'cmdline.skip_format'};
-
             require Perinci::CmdLine::Base;
             no warnings 'once';
             $copts{help} = $Perinci::CmdLine::Base::copts{help};
@@ -686,7 +693,7 @@ _
         push @l, "# display result\n\n";
         push @l, "{\n";
         push @l, 'my $fres;', "\n";
-        push @l, 'if (', ($meta->{'cmdline.skip_format'} ? 1:0), ' || $_pci_r->{res}[3]{"cmdline.skip_format"}) { $fres = $_pci_r->{res}[2] } else { require Inlined::_pci_format_result; $fres = _pci_format_result($_pci_r) }', "\n";
+        push @l, 'if (', ($skip_format ? 1:0), ' || $_pci_r->{res}[3]{"cmdline.skip_format"}) { $fres = $_pci_r->{res}[2] } else { require Inlined::_pci_format_result; $fres = _pci_format_result($_pci_r) }', "\n";
         push @l, 'print $fres;', "\n";
         push @l, "}\n\n";
 
@@ -820,7 +827,7 @@ Perinci::CmdLine::Inline - Generate inline Perinci::CmdLine CLI script
 
 =head1 VERSION
 
-This document describes version 0.14 of Perinci::CmdLine::Inline (from Perl distribution Perinci-CmdLine-Inline), released on 2015-07-06.
+This document describes version 0.15 of Perinci::CmdLine::Inline (from Perl distribution Perinci-CmdLine-Inline), released on 2015-07-08.
 
 =head1 SYNOPSIS
 
@@ -846,23 +853,23 @@ B<EARLY DEVELOPMENT.>
 
 Sample startup overhead benchmark vs Perinci::CmdLine::Lite:
 
-                                     Rate  run 1 (lite) run --version (lite)     -c (lite) run 1 (inline) run --version (inline)   -c (inline)   perl
- run 1 (lite)           21.1108+-0.0094/s            --               -62.9%        -83.3%         -89.2%                 -91.6%        -93.8% -97.4%
- run --version (lite)     56.935+-0.032/s 169.69+-0.19%                   --        -55.0%         -71.0%                 -77.4%        -83.2% -93.0%
- -c (lite)               126.433+-0.073/s        498.9%        122.07+-0.18%            --         -35.5%                 -49.7%        -62.6% -84.4%
- run 1 (inline)             196.1+-0.33/s   828.9+-1.6%         244.44+-0.6%   55.1+-0.27%             --                 -22.0%        -42.1% -75.8%
- run --version (inline)    251.53+-0.18/s       1091.5%         341.78+-0.4%  98.94+-0.18%   28.26+-0.23%                     --        -25.7% -69.0%
- -c (inline)                338.5+-0.46/s  1503.4+-2.3%        494.53+-0.87% 167.73+-0.39%   72.61+-0.37%           34.58+-0.21%            -- -58.3%
- perl                      811.32+-0.32/s       3743.2%              1325.0%        541.7%  313.72+-0.71%          222.56+-0.27% 139.68+-0.34%     --
+                                   Rate  run 1 (lite) run --version (lite)   -c (lite) run 1 (inline) run --version (inline) -c (inline)   perl
+ run 1 (lite)           13.515+-0.028/s            --               -61.5%      -82.3%         -89.2%                 -91.2%      -91.6% -97.4%
+ run --version (lite)    35.07+-0.074/s 159.48+-0.77%                   --      -54.0%         -72.0%                 -77.1%      -78.1% -93.2%
+ -c (lite)                76.23+-0.46/s     464+-3.6%          117.4+-1.4%          --         -39.2%                 -50.2%      -52.5% -85.3%
+ run 1 (inline)          125.41+-0.29/s   827.9+-2.9%          257.6+-1.1%  64.5+-1.1%             --                 -18.1%      -21.8% -75.8%
+ run --version (inline)  153.12+-0.98/s  1032.9+-7.6%          336.6+-2.9% 100.9+-1.8%    22.1+-0.83%                     --       -4.6% -70.5%
+ -c (inline)               160.5+-2.9/s     1087+-22%          357.5+-8.4%   110.5+-4%       28+-2.3%                4.8+-2%          -- -69.1%
+ perl                      519.1+-1.9/s     3741+-16%         1380.3+-6.2%   581+-4.8%      314+-1.8%              239+-2.5%   223.5+-6%     --
  
  Average times:
-   perl                  :     1.2326ms
-   -c (inline)           :     2.9542ms
-   run --version (inline):     3.9757ms
-   run 1 (inline)        :     5.0994ms
-   -c (lite)             :     7.9093ms
-   run --version (lite)  :    17.5639ms
-   run 1 (lite)          :    47.3691ms
+   perl                  :     1.9264ms
+   -c (inline)           :     6.2305ms
+   run --version (inline):     6.5308ms
+   run 1 (inline)        :     7.9738ms
+   -c (lite)             :    13.1182ms
+   run --version (lite)  :    28.5144ms
+   run 1 (lite)          :    73.9919ms
 
 =head1 FUNCTIONS
 
@@ -1036,6 +1043,10 @@ Currently does nothing, provided only for compatibility with Perinci::CmdLine::B
 
 Set shebang line.
 
+=item * B<skip_format> => I<bool> (default: 0)
+
+Assume that function returns raw text that need no formatting, do not offer --format, --json, --naked-res.
+
 =item * B<sub_name> => I<str>
 
 =item * B<subcommands> => I<any>
